@@ -18,7 +18,7 @@ package downloader
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io"
 	"log"
 	"os"
 	"path/filepath"
@@ -213,7 +213,7 @@ func TestCleanUp(t *testing.T) {
 	t.Run("test cache clean up", func(t *testing.T) {
 
 		// create temp dir
-		tempDir, err := ioutil.TempDir("", "")
+		tempDir, err := os.MkdirTemp("", "")
 		if err != nil {
 			t.Errorf("failed to create temp dir. error: '%v'", err)
 		}
@@ -238,7 +238,7 @@ func TestDownloadRemoteModule(t *testing.T) {
 
 	// disable terraform logs when TF_LOG env variable is not set
 	if os.Getenv("TF_LOG") == "" {
-		log.SetOutput(ioutil.Discard)
+		log.SetOutput(io.Discard)
 	}
 
 	testConstraintsSecurityGroup, _ := version.NewConstraint("3.17.0")
@@ -597,7 +597,7 @@ func TestBuildDiscoServices(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			testRCFilePath := filepath.Join(testDirPath, tt.filename)
-			b, err := ioutil.ReadFile(testRCFilePath)
+			b, err := os.ReadFile(testRCFilePath)
 			if err != nil {
 				t.Errorf("Error reading %s: %s", testRCFilePath, err)
 				return
